@@ -1,20 +1,9 @@
-// Copyright 2019 The kurbo Authors.
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-// https://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
+// Copyright 2019 the Kurbo Authors
+// SPDX-License-Identifier: Apache-2.0 OR MIT
 
 //! A description of the distances between the edges of two rectangles.
 
-use std::ops::{Add, Neg, Sub};
+use core::ops::{Add, Div, Mul, Neg, Sub};
 
 use crate::{Rect, Size};
 
@@ -117,7 +106,7 @@ impl Insets {
     pub const ZERO: Insets = Insets::uniform(0.);
 
     /// New uniform insets.
-    #[inline]
+    #[inline(always)]
     pub const fn uniform(d: f64) -> Insets {
         Insets {
             x0: d,
@@ -128,7 +117,7 @@ impl Insets {
     }
 
     /// New insets with uniform values along each axis.
-    #[inline]
+    #[inline(always)]
     pub const fn uniform_xy(x: f64, y: f64) -> Insets {
         Insets {
             x0: x,
@@ -140,7 +129,7 @@ impl Insets {
 
     /// New insets. The ordering of the arguments is "left, top, right, bottom",
     /// assuming a y-down coordinate space.
-    #[inline]
+    #[inline(always)]
     pub const fn new(x0: f64, y0: f64, x1: f64, y1: f64) -> Insets {
         Insets { x0, y0, x1, y1 }
     }
@@ -236,13 +225,13 @@ impl Insets {
 
     /// Are these insets finite?
     #[inline]
-    pub fn is_finite(&self) -> bool {
+    pub const fn is_finite(&self) -> bool {
         self.x0.is_finite() && self.y0.is_finite() && self.x1.is_finite() && self.y1.is_finite()
     }
 
     /// Are these insets NaN?
     #[inline]
-    pub fn is_nan(&self) -> bool {
+    pub const fn is_nan(&self) -> bool {
         self.x0.is_nan() || self.y0.is_nan() || self.x1.is_nan() || self.y1.is_nan()
     }
 }
@@ -290,6 +279,32 @@ impl Sub<Rect> for Insets {
     }
 }
 
+impl Mul<f64> for Insets {
+    type Output = Insets;
+
+    fn mul(self, rhs: f64) -> Self::Output {
+        Self {
+            x0: self.x0 * rhs,
+            y0: self.y0 * rhs,
+            x1: self.x1 * rhs,
+            y1: self.y1 * rhs,
+        }
+    }
+}
+
+impl Div<f64> for Insets {
+    type Output = Insets;
+
+    fn div(self, rhs: f64) -> Self::Output {
+        Self {
+            x0: self.x0 / rhs,
+            y0: self.y0 / rhs,
+            x1: self.x1 / rhs,
+            y1: self.y1 / rhs,
+        }
+    }
+}
+
 impl Sub<Insets> for Rect {
     type Output = Rect;
 
@@ -300,18 +315,21 @@ impl Sub<Insets> for Rect {
 }
 
 impl From<f64> for Insets {
+    #[inline(always)]
     fn from(src: f64) -> Insets {
         Insets::uniform(src)
     }
 }
 
 impl From<(f64, f64)> for Insets {
+    #[inline(always)]
     fn from(src: (f64, f64)) -> Insets {
         Insets::uniform_xy(src.0, src.1)
     }
 }
 
 impl From<(f64, f64, f64, f64)> for Insets {
+    #[inline(always)]
     fn from(src: (f64, f64, f64, f64)) -> Insets {
         Insets::new(src.0, src.1, src.2, src.3)
     }
