@@ -127,6 +127,12 @@ impl F2DOT14 {
     pub fn to_f32(self) -> f32 {
         f32::from(self.0) / 16384.0
     }
+
+    #[cfg(feature = "variable-fonts")]
+    #[inline]
+    pub fn apply_float_delta(&self, delta: f32) -> f32 {
+        self.to_f32() + (delta as f64 * (1.0 / 16384.0)) as f32
+    }
 }
 
 impl FromData for F2DOT14 {
@@ -152,6 +158,14 @@ impl FromData for Fixed {
     }
 }
 
+impl Fixed {
+    #[cfg(feature = "variable-fonts")]
+    #[inline]
+    pub(crate) fn apply_float_delta(&self, delta: f32) -> f32 {
+        self.0 + (delta as f64 * (1.0 / 65536.0)) as f32
+    }
+}
+
 /// A safe u32 to usize casting.
 ///
 /// Rust doesn't implement `From<u32> for usize`,
@@ -224,10 +238,10 @@ impl TryNumFrom<f32> for i32 {
 
         // We can't represent `MIN-1` exactly, but there's no fractional part
         // at this magnitude, so we can just use a `MIN` inclusive boundary.
-        const MIN: f32 = core::i32::MIN as f32;
+        const MIN: f32 = i32::MIN as f32;
         // We can't represent `MAX` exactly, but it will round up to exactly
         // `MAX+1` (a power of two) when we cast it.
-        const MAX_P1: f32 = core::i32::MAX as f32;
+        const MAX_P1: f32 = i32::MAX as f32;
         if v >= MIN && v < MAX_P1 {
             Some(v as i32)
         } else {
@@ -358,7 +372,7 @@ impl<'a, T: FromData> LazyArray16<'a, T> {
 
 impl<'a, T: FromData + core::fmt::Debug + Copy> core::fmt::Debug for LazyArray16<'a, T> {
     fn fmt(&self, f: &mut core::fmt::Formatter) -> core::fmt::Result {
-        f.debug_list().entries(self.into_iter()).finish()
+        f.debug_list().entries(*self).finish()
     }
 }
 
@@ -508,7 +522,7 @@ impl<'a, T: FromData> LazyArray32<'a, T> {
 
 impl<'a, T: FromData + core::fmt::Debug + Copy> core::fmt::Debug for LazyArray32<'a, T> {
     fn fmt(&self, f: &mut core::fmt::Formatter) -> core::fmt::Result {
-        f.debug_list().entries(self.into_iter()).finish()
+        f.debug_list().entries(*self).finish()
     }
 }
 
@@ -608,7 +622,7 @@ impl<'a, T: FromSlice<'a>> LazyOffsetArray16<'a, T> {
 
 impl<'a, T: FromSlice<'a> + core::fmt::Debug + Copy> core::fmt::Debug for LazyOffsetArray16<'a, T> {
     fn fmt(&self, f: &mut core::fmt::Formatter) -> core::fmt::Result {
-        f.debug_list().entries(self.into_iter()).finish()
+        f.debug_list().entries(*self).finish()
     }
 }
 
@@ -750,6 +764,11 @@ impl<'a> Stream<'a> {
     /// Reads N bytes from the stream.
     #[inline]
     pub fn read_bytes(&mut self, len: usize) -> Option<&'a [u8]> {
+        // An integer overflow here on 32bit systems is almost guarantee to be caused
+        // by an incorrect parsing logic from the caller side.
+        // Simply using `checked_add` here would silently swallow errors, which is not what we want.
+        debug_assert!(self.offset as u64 + len as u64 <= u32::MAX as u64);
+
         let v = self.data.get(self.offset..self.offset + len)?;
         self.advance(len);
         Some(v)
@@ -771,7 +790,7 @@ impl<'a> Stream<'a> {
 
     #[allow(dead_code)]
     #[inline]
-    pub(crate) fn read_at_offset16(&mut self, data: &'a [u8]) -> Option<&'a [u8]> {
+    pub fn read_at_offset16(&mut self, data: &'a [u8]) -> Option<&'a [u8]> {
         let offset = self.read::<Offset16>()?.to_usize();
         data.get(offset..)
     }
@@ -781,11 +800,6 @@ impl<'a> Stream<'a> {
 pub trait Offset {
     /// Converts the offset to `usize`.
     fn to_usize(&self) -> usize;
-
-    /// Checks that offset is null.
-    fn is_null(&self) -> bool {
-        self.to_usize() == 0
-    }
 }
 
 /// A type-safe u16 offset.
@@ -822,6 +836,40 @@ impl FromData for Option<Offset16> {
     }
 }
 
+/// A type-safe u24 offset.
+#[derive(Clone, Copy, Debug)]
+pub struct Offset24(pub u32);
+
+impl Offset for Offset24 {
+    #[inline]
+    fn to_usize(&self) -> usize {
+        usize::num_from(self.0)
+    }
+}
+
+impl FromData for Offset24 {
+    const SIZE: usize = 3;
+
+    #[inline]
+    fn parse(data: &[u8]) -> Option<Self> {
+        U24::parse(data).map(|n| Offset24(n.0))
+    }
+}
+
+impl FromData for Option<Offset24> {
+    const SIZE: usize = Offset24::SIZE;
+
+    #[inline]
+    fn parse(data: &[u8]) -> Option<Self> {
+        let offset = Offset24::parse(data)?;
+        if offset.0 != 0 {
+            Some(Some(offset))
+        } else {
+            Some(None)
+        }
+    }
+}
+
 /// A type-safe u32 offset.
 #[derive(Clone, Copy, Debug)]
 pub struct Offset32(pub u32);
@@ -857,13 +905,13 @@ impl FromData for Option<Offset32> {
 }
 
 #[inline]
-pub(crate) fn i16_bound(min: i16, val: i16, max: i16) -> i16 {
+pub fn i16_bound(min: i16, val: i16, max: i16) -> i16 {
     use core::cmp;
     cmp::max(min, cmp::min(max, val))
 }
 
 #[inline]
-pub(crate) fn f32_bound(min: f32, val: f32, max: f32) -> f32 {
+pub fn f32_bound(min: f32, val: f32, max: f32) -> f32 {
     debug_assert!(min.is_finite());
     debug_assert!(val.is_finite());
     debug_assert!(max.is_finite());
